Polynomial
==========

.. toctree::
    :maxdepth: 1

    introduction
    polynomial_evaluation
    polynomial_expansion
    numpy_functions
    orthogonality
    truncation_scheme
    comparison_operators
    polynomial_division
